import Foundation
import AuthenticationServices

@objc(NotabeneSdk)
class NotabeneSdk: NSObject {
  @objc func open(_ url: String, deepLink: String, resolver resolve: @escaping RCTPromiseResolveBlock, rejecter reject: @escaping RCTPromiseRejectBlock) {
    guard let authURL = URL(string: url) else {
      reject("INVALID_URL", "The provided URL is invalid", nil)
      return
    }

    let scheme = URL(string: deepLink)?.scheme ?? ""

    let session = ASWebAuthenticationSession(url: authURL, callbackURLScheme: scheme) { callbackURL, error in
      if let error = error {
        reject("AUTH_ERROR", error.localizedDescription, error)
      } else if let callbackURL = callbackURL {
        resolve(callbackURL.absoluteString)
      } else {
        reject("UNKNOWN_ERROR", "An unknown error occurred", nil)
      }
    }

    session.presentationContextProvider = self

    DispatchQueue.main.async {
      session.start()
    }
  }
}

extension NotabeneSdk: ASWebAuthenticationPresentationContextProviding {
  func presentationAnchor(for session: ASWebAuthenticationSession) -> ASPresentationAnchor {
    return UIApplication.shared.windows.first ?? ASPresentationAnchor()
  }
}
