"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EmbeddedComponentRN = void 0;
var _javascriptSdk = require("@notabene/javascript-sdk");
var _notabeneSdk = require("./notabene-sdk.js");
function isTransactionResponse(response) {
  return response.type === _javascriptSdk.CMType.COMPLETE;
}
function isCancelResponse(response) {
  return response.type === _javascriptSdk.CMType.CANCEL;
}
function isErrorResponse(response) {
  return response.type === _javascriptSdk.CMType.ERROR;
}
class EmbeddedComponentRN extends _javascriptSdk.EmbeddedComponent {
  constructor(url, deepLink, value) {
    super(url, value);
    this.deepLink = deepLink;
  }
  async openModal() {
    try {
      // get the string response from Native
      const response = await openComponent(this.url, this.deepLink);

      // Parse the response to check for conclusive errors from the JS SDK
      const [_, fragment] = response.split('#');
      const params = new URLSearchParams(fragment);
      const encodedMessage = params.has('message') ? params.get('message') : undefined;
      const parsedResponse = {
        ...(encodedMessage ? JSON.parse(encodedMessage) : {})
      };
      if (isTransactionResponse(parsedResponse)) {
        if (parsedResponse.response) {
          return parsedResponse.response;
        }
      }
      if (isCancelResponse(parsedResponse)) {
        return Promise.reject({
          ...parsedResponse,
          message: 'User cancellation',
          deepLink: response
        });
      }
      if (isErrorResponse(parsedResponse)) {
        return Promise.reject({
          ...parsedResponse,
          message: parsedResponse?.description || parsedResponse?.message,
          deepLink: response
        });
      }
      return Promise.reject({
        ...parsedResponse,
        message: 'Unknown error',
        deepLink: response
      });
    } catch (ex) {
      const error = ex;
      if (error.message?.includes('The operation couldn’t be completed')) {
        return Promise.reject('User cancellation');
      }
      return Promise.reject(error);
    }
  }
}
exports.EmbeddedComponentRN = EmbeddedComponentRN;
async function openComponent(url, deepLink) {
  return await _notabeneSdk.NotabeneSdk.open(url, deepLink);
}
//# sourceMappingURL=embedded-component.js.map