"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EmbeddedComponentRN", {
  enumerable: true,
  get: function () {
    return _embeddedComponent.EmbeddedComponentRN;
  }
});
exports.default = void 0;
require("react-native-url-polyfill/auto");
var _javascriptSdk = _interopRequireDefault(require("@notabene/javascript-sdk"));
var _embeddedComponent = require("./embedded-component.js");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class NotabeneRN extends _javascriptSdk.default {
  constructor(config) {
    if (!config.uxUrl?.length) {
      throw new Error('Notabene `uxUrl` is required');
    }
    if (!config.nodeUrl?.length) {
      throw new Error('Notabene `nodeUrl` is required');
    }
    if (!config.authToken?.length) {
      throw new Error('Notabene `authToken` is required');
    }
    if (!config.resultDeepLink?.length) {
      throw new Error('Notabene `resultDeepLink` is required');
    }
    super(config);
    this.resultDeepLink = config.resultDeepLink;
    this.componentDeepLink = config.componentDeepLink;
  }

  /**
   * Creates a new embedded component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance
   * @internal
   */
  createComponent(path, value, options, callbacks) {
    return new _embeddedComponent.EmbeddedComponentRN(this.componentUrl(path, value, options, callbacks), this.resultDeepLink, value);
  }

  /**
   * Generates a URL for a Notabene component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param configuration - Optional transaction configuration
   * @param callbacks - Optional callback configuration
   * @returns component URL
   * @internal
   */
  componentUrl(path, value, configuration, callbacks) {
    const url = super.componentUrl(path, value, configuration, callbacks);
    const sdkUrl = new URL(url);
    sdkUrl.searchParams.set('redirect_uri', this.resultDeepLink);
    return sdkUrl.toString();
  }

  /**
   * Creates a connect component
   *
   * @param value - Connection request data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance for connection
   */
  createConnectWallet(value, options, callbacks) {
    return this.createComponent('connect', value, options, callbacks);
  }

  /**
   * Creates a deposit request component
   *
   * @param value - Deposit request data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance for deposit requests
   * @public
   */
  createDepositRequest(value, options, callbacks) {
    return this.createComponent('deposit-request', value, options, callbacks);
  }

  /**
   * Creates a withdrawal assist component
   *
   * @param value - Withdrawal transaction data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance for withdrawal assistance
   */
  createWithdrawalAssist(value, options, callbacks) {
    return this.createComponent('withdrawal-assist', value, options, callbacks);
  }

  /**
   * Creates a deposit assist component
   *
   * @param value - Deposit transaction data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance for deposit assistance
   */
  createDepositAssist(value, options, callbacks) {
    return this.createComponent('deposit-assist', value, options, callbacks);
  }
}
exports.default = NotabeneRN;
//# sourceMappingURL=index.js.map