"use strict";

import { CMType, EmbeddedComponent } from '@notabene/javascript-sdk';
import { NotabeneSdk } from "./notabene-sdk.js";
function isTransactionResponse(response) {
  return response.type === CMType.COMPLETE;
}
function isCancelResponse(response) {
  return response.type === CMType.CANCEL;
}
function isErrorResponse(response) {
  return response.type === CMType.ERROR;
}
export class EmbeddedComponentRN extends EmbeddedComponent {
  constructor(url, deepLink, value) {
    super(url, value);
    this.deepLink = deepLink;
  }
  async openModal() {
    try {
      // get the string response from Native
      const response = await openComponent(this.url, this.deepLink);

      // Parse the response to check for conclusive errors from the JS SDK
      const [_, fragment] = response.split('#');
      const params = new URLSearchParams(fragment);
      const encodedMessage = params.has('message') ? params.get('message') : undefined;
      const parsedResponse = {
        ...(encodedMessage ? JSON.parse(encodedMessage) : {})
      };
      if (isTransactionResponse(parsedResponse)) {
        if (parsedResponse.response) {
          return parsedResponse.response;
        }
      }
      if (isCancelResponse(parsedResponse)) {
        return Promise.reject({
          ...parsedResponse,
          message: 'User cancellation',
          deepLink: response
        });
      }
      if (isErrorResponse(parsedResponse)) {
        return Promise.reject({
          ...parsedResponse,
          message: parsedResponse?.description || parsedResponse?.message,
          deepLink: response
        });
      }
      return Promise.reject({
        ...parsedResponse,
        message: 'Unknown error',
        deepLink: response
      });
    } catch (ex) {
      const error = ex;
      if (error.message?.includes('The operation couldn’t be completed')) {
        return Promise.reject('User cancellation');
      }
      return Promise.reject(error);
    }
  }
}
async function openComponent(url, deepLink) {
  return await NotabeneSdk.open(url, deepLink);
}
//# sourceMappingURL=embedded-component.js.map