import 'react-native-url-polyfill/auto';
import Notabene, { type CallbackOptions, type ConnectionOptions, type ConnectionRequest, type Deposit, type DepositRequest, type DepositRequestOptions, type NotabeneConfig, type TransactionOptions, type Withdrawal } from '@notabene/javascript-sdk';
import { EmbeddedComponentRN } from './embedded-component';
export { type TransactionResponseRN, EmbeddedComponentRN, } from './embedded-component';
export interface NotabeneRNConfig extends NotabeneConfig {
    componentDeepLink?: string;
    resultDeepLink: string;
}
export default class NotabeneRN extends Notabene {
    componentDeepLink?: string;
    resultDeepLink: string;
    constructor(config: NotabeneRNConfig);
    /**
     * Creates a new embedded component
     *
     * @param path - The path of the component
     * @param value - Transaction data
     * @param options - Optional transaction options
     * @param callbacks - Optional callback configuration
     * @returns A new EmbeddedComponent instance
     * @internal
     */
    createComponent<V, O>(path: string, value: Partial<V>, options?: O, callbacks?: CallbackOptions): EmbeddedComponentRN<V, O>;
    /**
     * Generates a URL for a Notabene component
     *
     * @param path - The path of the component
     * @param value - Transaction data
     * @param configuration - Optional transaction configuration
     * @param callbacks - Optional callback configuration
     * @returns component URL
     * @internal
     */
    componentUrl<V, O>(path: string, value: V, configuration?: O, callbacks?: CallbackOptions): string;
    /**
     * Creates a connect component
     *
     * @param value - Connection request data
     * @param options - Optional transaction options
     * @param callbacks - Optional callback configuration
     * @returns A new EmbeddedComponent instance for connection
     */
    createConnectWallet(value: ConnectionRequest, options?: ConnectionOptions, callbacks?: CallbackOptions): EmbeddedComponentRN<ConnectionRequest, ConnectionOptions>;
    /**
     * Creates a deposit request component
     *
     * @param value - Deposit request data
     * @param options - Optional transaction options
     * @param callbacks - Optional callback configuration
     * @returns A new EmbeddedComponent instance for deposit requests
     * @public
     */
    createDepositRequest(value: DepositRequest, options?: DepositRequestOptions, callbacks?: CallbackOptions): EmbeddedComponentRN<DepositRequest, DepositRequestOptions>;
    /**
     * Creates a withdrawal assist component
     *
     * @param value - Withdrawal transaction data
     * @param options - Optional transaction options
     * @param callbacks - Optional callback configuration
     * @returns A new EmbeddedComponent instance for withdrawal assistance
     */
    createWithdrawalAssist(value: Partial<Withdrawal>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponentRN<Withdrawal, TransactionOptions>;
    /**
     * Creates a deposit assist component
     *
     * @param value - Deposit transaction data
     * @param options - Optional transaction options
     * @param callbacks - Optional callback configuration
     * @returns A new EmbeddedComponent instance for deposit assistance
     */
    createDepositAssist(value: Partial<Deposit>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponentRN<Deposit, TransactionOptions>;
}
//# sourceMappingURL=index.d.ts.map